<?php

namespace Litematrimony\Profile\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Litematrimony\Profile\Interfaces\ShortlistRepositoryInterface;
use Litematrimony\Profile\Repositories\Eloquent\Filters\ShortlistPublicFilter;
use Litematrimony\Profile\Repositories\Eloquent\Presenters\ShortlistListPresenter;

class ShortlistPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        ShortlistRepositoryInterface $shortlist
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('litematrimony.profile.modules'), 'shortlist', guard_url('shortlist'));
        $this->repository = $shortlist;
    }

    /**
     * Show shortlist's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(ShortlistPublicFilter::class)
            ->setPresenter(ShortlistListPresenter::class)
            ->select('shortlists.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('profile::shortlist.names'))
            ->view('profile::public.shortlist.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show shortlist.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('profile::shortlist.name'))
            ->view('profile::public.shortlist.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
