<?php

namespace Litematrimony\Profile\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Litematrimony\Profile\Interfaces\VisitRepositoryInterface;
use Litematrimony\Profile\Repositories\Eloquent\Filters\VisitPublicFilter;
use Litematrimony\Profile\Repositories\Eloquent\Presenters\VisitListPresenter;

class VisitPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        VisitRepositoryInterface $visit
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('litematrimony.profile.modules'), 'visit', guard_url('visit'));
        $this->repository = $visit;
    }

    /**
     * Show visit's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(VisitPublicFilter::class)
            ->setPresenter(VisitListPresenter::class)
            ->select('visits.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('profile::visit.names'))
            ->view('profile::public.visit.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show visit.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('profile::visit.name'))
            ->view('profile::public.visit.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
