<?php

namespace Litematrimony\Profile\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litematrimony\Profile\Models\Visit;

class VisitPolicy
{

    /**
     * Determine if the given user can view the visit.
     *
     * @param UserPolicyInterface $authUser
     * @param Visit $visit
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Visit $visit)
    {
        if ($authUser->canDo('profile.visit.view') && $authUser->isAdmin()) {
            return true;
        }

        return $visit->user_id == user_id() && $visit->user_type == user_type();
    }

    /**
     * Determine if the given user can create a visit.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('profile.visit.create');
    }

    /**
     * Determine if the given user can update the given visit.
     *
     * @param UserPolicyInterface $authUser
     * @param Visit $visit
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Visit $visit)
    {
        if ($authUser->canDo('profile.visit.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $visit->user_id == user_id() && $visit->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given visit.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Visit $visit)
    {
        return $visit->user_id == user_id() && $visit->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given visit.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Visit $visit)
    {
        if ($authUser->canDo('profile.visit.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given visit.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Visit $visit)
    {
        if ($authUser->canDo('profile.visit.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
